@@ -1,87 +1,49 @@
+pub type PFNMSGECALLBACK = Option<unsafe extern "system" fn(bverbose: windows_core::BOOL, lpmessage: windows_core::PCWSTR) -> u32>;
+pub type PWLX_ASSIGN_SHELL_PROTECTION = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, htoken: super::super::Foundation::HANDLE, hprocess: super::super::Foundation::HANDLE, hthread: super::super::Foundation::HANDLE) -> i32>;
+pub type PWLX_CHANGE_PASSWORD_NOTIFY = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, pmprinfo: *mut WLX_MPR_NOTIFY_INFO, dwchangeinfo: u32) -> i32>;
+pub type PWLX_CHANGE_PASSWORD_NOTIFY_EX = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, pmprinfo: *mut WLX_MPR_NOTIFY_INFO, dwchangeinfo: u32, providername: windows_core::PCWSTR, reserved: *mut core::ffi::c_void) -> i32>;
+#[cfg(feature = "Win32_System_StationsAndDesktops")]
+pub type PWLX_CLOSE_USER_DESKTOP = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, pdesktop: *mut WLX_DESKTOP, htoken: super::super::Foundation::HANDLE) -> windows_core::BOOL>;
+#[cfg(feature = "Win32_System_StationsAndDesktops")]
+pub type PWLX_CREATE_USER_DESKTOP = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, htoken: super::super::Foundation::HANDLE, flags: u32, pszdesktopname: windows_core::PCWSTR, ppdesktop: *mut *mut WLX_DESKTOP) -> windows_core::BOOL>;
+#[cfg(feature = "Win32_UI_WindowsAndMessaging")]
+pub type PWLX_DIALOG_BOX = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, hinst: super::super::Foundation::HANDLE, lpsztemplate: windows_core::PCWSTR, hwndowner: super::super::Foundation::HWND, dlgprc: super::super::UI::WindowsAndMessaging::DLGPROC) -> i32>;
+#[cfg(feature = "Win32_UI_WindowsAndMessaging")]
+pub type PWLX_DIALOG_BOX_INDIRECT = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, hinst: super::super::Foundation::HANDLE, hdialogtemplate: *mut super::super::UI::WindowsAndMessaging::DLGTEMPLATE, hwndowner: super::super::Foundation::HWND, dlgprc: super::super::UI::WindowsAndMessaging::DLGPROC) -> i32>;
+#[cfg(feature = "Win32_UI_WindowsAndMessaging")]
+pub type PWLX_DIALOG_BOX_INDIRECT_PARAM = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, hinst: super::super::Foundation::HANDLE, hdialogtemplate: *mut super::super::UI::WindowsAndMessaging::DLGTEMPLATE, hwndowner: super::super::Foundation::HWND, dlgprc: super::super::UI::WindowsAndMessaging::DLGPROC, dwinitparam: super::super::Foundation::LPARAM) -> i32>;
+#[cfg(feature = "Win32_UI_WindowsAndMessaging")]
+pub type PWLX_DIALOG_BOX_PARAM = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, hinst: super::super::Foundation::HANDLE, lpsztemplate: windows_core::PCWSTR, hwndowner: super::super::Foundation::HWND, dlgprc: super::super::UI::WindowsAndMessaging::DLGPROC, dwinitparam: super::super::Foundation::LPARAM) -> i32>;
+pub type PWLX_DISCONNECT = Option<unsafe extern "system" fn() -> windows_core::BOOL>;
+pub type PWLX_GET_OPTION = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, option: u32, value: *mut usize) -> windows_core::BOOL>;
+#[cfg(feature = "Win32_System_StationsAndDesktops")]
+pub type PWLX_GET_SOURCE_DESKTOP = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, ppdesktop: *mut *mut WLX_DESKTOP) -> windows_core::BOOL>;
+pub type PWLX_MESSAGE_BOX = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, hwndowner: super::super::Foundation::HWND, lpsztext: windows_core::PCWSTR, lpsztitle: windows_core::PCWSTR, fustyle: u32) -> i32>;
+pub type PWLX_QUERY_CLIENT_CREDENTIALS = Option<unsafe extern "system" fn(pcred: *mut WLX_CLIENT_CREDENTIALS_INFO_V1_0) -> windows_core::BOOL>;
+pub type PWLX_QUERY_CONSOLESWITCH_CREDENTIALS = Option<unsafe extern "system" fn(pcred: *mut WLX_CONSOLESWITCH_CREDENTIALS_INFO_V1_0) -> u32>;
+pub type PWLX_QUERY_IC_CREDENTIALS = Option<unsafe extern "system" fn(pcred: *mut WLX_CLIENT_CREDENTIALS_INFO_V1_0) -> windows_core::BOOL>;
+pub type PWLX_QUERY_TERMINAL_SERVICES_DATA = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, ptsdata: *mut WLX_TERMINAL_SERVICES_DATA, username: windows_core::PCWSTR, domain: windows_core::PCWSTR) -> u32>;
+pub type PWLX_QUERY_TS_LOGON_CREDENTIALS = Option<unsafe extern "system" fn(pcred: *mut WLX_CLIENT_CREDENTIALS_INFO_V2_0) -> windows_core::BOOL>;
+pub type PWLX_SAS_NOTIFY = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, dwsastype: u32)>;
+pub type PWLX_SET_CONTEXT_POINTER = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, pwlxcontext: *mut core::ffi::c_void)>;
+pub type PWLX_SET_OPTION = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, option: u32, value: usize, oldvalue: *mut usize) -> windows_core::BOOL>;
+#[cfg(feature = "Win32_System_StationsAndDesktops")]
+pub type PWLX_SET_RETURN_DESKTOP = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, pdesktop: *mut WLX_DESKTOP) -> windows_core::BOOL>;
+pub type PWLX_SET_TIMEOUT = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, timeout: u32) -> windows_core::BOOL>;
+pub type PWLX_SWITCH_DESKTOP_TO_USER = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE) -> i32>;
+pub type PWLX_SWITCH_DESKTOP_TO_WINLOGON = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE) -> i32>;
+pub type PWLX_USE_CTRL_ALT_DEL = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE)>;
+pub type PWLX_WIN31_MIGRATE = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE)>;
 pub const STATUSMSG_OPTION_NOANIMATION: u32 = 1u32;
 pub const STATUSMSG_OPTION_SETFOREGROUND: u32 = 2u32;
-pub const WLX_CONSOLESWITCHCREDENTIAL_TYPE_V1_0: u32 = 1u32;
-pub const WLX_CREATE_INSTANCE_ONLY: u32 = 1u32;
-pub const WLX_CREATE_USER: u32 = 2u32;
-pub const WLX_CREDENTIAL_TYPE_V1_0: u32 = 1u32;
-pub const WLX_CREDENTIAL_TYPE_V2_0: u32 = 2u32;
-pub const WLX_CURRENT_VERSION: u32 = 65540u32;
-pub const WLX_DESKTOP_HANDLE: u32 = 2u32;
-pub const WLX_DESKTOP_NAME: u32 = 1u32;
-pub const WLX_DIRECTORY_LENGTH: u32 = 256u32;
-pub const WLX_DLG_INPUT_TIMEOUT: u32 = 102u32;
-pub const WLX_DLG_SAS: u32 = 101u32;
-pub const WLX_DLG_SCREEN_SAVER_TIMEOUT: u32 = 103u32;
-pub const WLX_DLG_USER_LOGOFF: u32 = 104u32;
-pub const WLX_LOGON_OPT_NO_PROFILE: u32 = 1u32;
-pub const WLX_OPTION_CONTEXT_POINTER: u32 = 2u32;
-pub const WLX_OPTION_DISPATCH_TABLE_SIZE: u32 = 65539u32;
-pub const WLX_OPTION_FORCE_LOGOFF_TIME: u32 = 4u32;
-pub const WLX_OPTION_IGNORE_AUTO_LOGON: u32 = 8u32;
-pub const WLX_OPTION_NO_SWITCH_ON_SAS: u32 = 9u32;
-pub const WLX_OPTION_SMART_CARD_INFO: u32 = 65538u32;
-pub const WLX_OPTION_SMART_CARD_PRESENT: u32 = 65537u32;
-pub const WLX_OPTION_USE_CTRL_ALT_DEL: u32 = 1u32;
-pub const WLX_OPTION_USE_SMART_CARD: u32 = 3u32;
-pub const WLX_PROFILE_TYPE_V1_0: u32 = 1u32;
-pub const WLX_PROFILE_TYPE_V2_0: u32 = 2u32;
-pub const WLX_SAS_ACTION_DELAYED_FORCE_LOGOFF: u32 = 16u32;
-pub const WLX_SAS_ACTION_FORCE_LOGOFF: u32 = 9u32;
-pub const WLX_SAS_ACTION_LOCK_WKSTA: u32 = 3u32;
-pub const WLX_SAS_ACTION_LOGOFF: u32 = 4u32;
-pub const WLX_SAS_ACTION_LOGON: u32 = 1u32;
-pub const WLX_SAS_ACTION_NONE: u32 = 2u32;
-pub const WLX_SAS_ACTION_PWD_CHANGED: u32 = 6u32;
-pub const WLX_SAS_ACTION_RECONNECTED: u32 = 15u32;
-pub const WLX_SAS_ACTION_SHUTDOWN: WLX_SHUTDOWN_TYPE = WLX_SHUTDOWN_TYPE(5u32);
-pub const WLX_SAS_ACTION_SHUTDOWN_HIBERNATE: u32 = 14u32;
-pub const WLX_SAS_ACTION_SHUTDOWN_POWER_OFF: WLX_SHUTDOWN_TYPE = WLX_SHUTDOWN_TYPE(10u32);
-pub const WLX_SAS_ACTION_SHUTDOWN_REBOOT: WLX_SHUTDOWN_TYPE = WLX_SHUTDOWN_TYPE(11u32);
-pub const WLX_SAS_ACTION_SHUTDOWN_SLEEP: u32 = 12u32;
-pub const WLX_SAS_ACTION_SHUTDOWN_SLEEP2: u32 = 13u32;
-pub const WLX_SAS_ACTION_SWITCH_CONSOLE: u32 = 17u32;
-pub const WLX_SAS_ACTION_TASKLIST: u32 = 7u32;
-pub const WLX_SAS_ACTION_UNLOCK_WKSTA: u32 = 8u32;
-pub const WLX_SAS_TYPE_AUTHENTICATED: u32 = 7u32;
-pub const WLX_SAS_TYPE_CTRL_ALT_DEL: u32 = 1u32;
-pub const WLX_SAS_TYPE_MAX_MSFT_VALUE: u32 = 127u32;
-pub const WLX_SAS_TYPE_SCRNSVR_ACTIVITY: u32 = 3u32;
-pub const WLX_SAS_TYPE_SCRNSVR_TIMEOUT: u32 = 2u32;
-pub const WLX_SAS_TYPE_SC_FIRST_READER_ARRIVED: u32 = 8u32;
-pub const WLX_SAS_TYPE_SC_INSERT: u32 = 5u32;
-pub const WLX_SAS_TYPE_SC_LAST_READER_REMOVED: u32 = 9u32;
-pub const WLX_SAS_TYPE_SC_REMOVE: u32 = 6u32;
-pub const WLX_SAS_TYPE_SWITCHUSER: u32 = 10u32;
-pub const WLX_SAS_TYPE_TIMEOUT: u32 = 0u32;
-pub const WLX_SAS_TYPE_USER_LOGOFF: u32 = 4u32;
-pub const WLX_VERSION_1_0: u32 = 65536u32;
-pub const WLX_VERSION_1_1: u32 = 65537u32;
-pub const WLX_VERSION_1_2: u32 = 65538u32;
-pub const WLX_VERSION_1_3: u32 = 65539u32;
-pub const WLX_VERSION_1_4: u32 = 65540u32;
-pub const WLX_WM_SAS: u32 = 1625u32;
-#[repr(transparent)]
-#[derive(PartialEq, Eq, Copy, Clone, Default)]
-pub struct WLX_SHUTDOWN_TYPE(pub u32);
-impl windows_core::TypeKind for WLX_SHUTDOWN_TYPE {
-    type TypeKind = windows_core::CopyType;
-}
-impl core::fmt::Debug for WLX_SHUTDOWN_TYPE {
-    fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
-        f.debug_tuple("WLX_SHUTDOWN_TYPE").field(&self.0).finish()
-    }
-}
 #[repr(C)]
-#[derive(Clone, Copy, Debug, Eq, PartialEq)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct WLX_CLIENT_CREDENTIALS_INFO_V1_0 {
     pub dwType: u32,
     pub pszUserName: windows_core::PWSTR,
     pub pszDomain: windows_core::PWSTR,
     pub pszPassword: windows_core::PWSTR,
-    pub fPromptForPassword: super::super::Foundation::BOOL,
-}
-impl windows_core::TypeKind for WLX_CLIENT_CREDENTIALS_INFO_V1_0 {
-    type TypeKind = windows_core::CopyType;
+    pub fPromptForPassword: windows_core::BOOL,
 }
 impl Default for WLX_CLIENT_CREDENTIALS_INFO_V1_0 {
     fn default() -> Self {
@@ -89,25 +51,23 @@ impl Default for WLX_CLIENT_CREDENTIALS_INFO_V1_0 {
     }
 }
 #[repr(C)]
-#[derive(Clone, Copy, Debug, Eq, PartialEq)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct WLX_CLIENT_CREDENTIALS_INFO_V2_0 {
     pub dwType: u32,
     pub pszUserName: windows_core::PWSTR,
     pub pszDomain: windows_core::PWSTR,
     pub pszPassword: windows_core::PWSTR,
-    pub fPromptForPassword: super::super::Foundation::BOOL,
-    pub fDisconnectOnLogonFailure: super::super::Foundation::BOOL,
-}
-impl windows_core::TypeKind for WLX_CLIENT_CREDENTIALS_INFO_V2_0 {
-    type TypeKind = windows_core::CopyType;
+    pub fPromptForPassword: windows_core::BOOL,
+    pub fDisconnectOnLogonFailure: windows_core::BOOL,
 }
 impl Default for WLX_CLIENT_CREDENTIALS_INFO_V2_0 {
     fn default() -> Self {
         unsafe { core::mem::zeroed() }
     }
 }
+pub const WLX_CONSOLESWITCHCREDENTIAL_TYPE_V1_0: u32 = 1u32;
 #[repr(C)]
-#[derive(Clone, Copy, Debug, Eq, PartialEq)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct WLX_CONSOLESWITCH_CREDENTIALS_INFO_V1_0 {
     pub dwType: u32,
     pub UserToken: super::super::Foundation::HANDLE,
@@ -116,7 +76,7 @@ pub struct WLX_CONSOLESWITCH_CREDENTIALS_INFO_V1_0 {
     pub UserName: windows_core::PWSTR,
     pub Domain: windows_core::PWSTR,
     pub LogonTime: i64,
-    pub SmartCardLogon: super::super::Foundation::BOOL,
+    pub SmartCardLogon: windows_core::BOOL,
     pub ProfileLength: u32,
     pub MessageType: u32,
     pub LogonCount: u16,
@@ -137,17 +97,19 @@ pub struct WLX_CONSOLESWITCH_CREDENTIALS_INFO_V1_0 {
     pub PrivateDataLen: u32,
     pub PrivateData: *mut u8,
 }
-impl windows_core::TypeKind for WLX_CONSOLESWITCH_CREDENTIALS_INFO_V1_0 {
-    type TypeKind = windows_core::CopyType;
-}
 impl Default for WLX_CONSOLESWITCH_CREDENTIALS_INFO_V1_0 {
     fn default() -> Self {
         unsafe { core::mem::zeroed() }
     }
 }
+pub const WLX_CREATE_INSTANCE_ONLY: u32 = 1u32;
+pub const WLX_CREATE_USER: u32 = 2u32;
+pub const WLX_CREDENTIAL_TYPE_V1_0: u32 = 1u32;
+pub const WLX_CREDENTIAL_TYPE_V2_0: u32 = 2u32;
+pub const WLX_CURRENT_VERSION: u32 = 65540u32;
 #[repr(C)]
 #[cfg(feature = "Win32_System_StationsAndDesktops")]
-#[derive(Clone, Copy, Debug, Eq, PartialEq)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct WLX_DESKTOP {
     pub Size: u32,
     pub Flags: u32,
@@ -155,18 +117,17 @@ pub struct WLX_DESKTOP {
     pub pszDesktopName: windows_core::PWSTR,
 }
 #[cfg(feature = "Win32_System_StationsAndDesktops")]
-impl windows_core::TypeKind for WLX_DESKTOP {
-    type TypeKind = windows_core::CopyType;
-}
-#[cfg(feature = "Win32_System_StationsAndDesktops")]
 impl Default for WLX_DESKTOP {
     fn default() -> Self {
         unsafe { core::mem::zeroed() }
     }
 }
+pub const WLX_DESKTOP_HANDLE: u32 = 2u32;
+pub const WLX_DESKTOP_NAME: u32 = 1u32;
+pub const WLX_DIRECTORY_LENGTH: u32 = 256u32;
 #[repr(C)]
 #[cfg(feature = "Win32_UI_WindowsAndMessaging")]
-#[derive(Clone, Copy, Debug)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct WLX_DISPATCH_VERSION_1_0 {
     pub WlxUseCtrlAltDel: PWLX_USE_CTRL_ALT_DEL,
     pub WlxSetContextPointer: PWLX_SET_CONTEXT_POINTER,
@@ -183,10 +144,6 @@ pub struct WLX_DISPATCH_VERSION_1_0 {
     pub WlxChangePasswordNotify: PWLX_CHANGE_PASSWORD_NOTIFY,
 }
 #[cfg(feature = "Win32_UI_WindowsAndMessaging")]
-impl windows_core::TypeKind for WLX_DISPATCH_VERSION_1_0 {
-    type TypeKind = windows_core::CopyType;
-}
-#[cfg(feature = "Win32_UI_WindowsAndMessaging")]
 impl Default for WLX_DISPATCH_VERSION_1_0 {
     fn default() -> Self {
         unsafe { core::mem::zeroed() }
@@ -194,7 +151,7 @@ impl Default for WLX_DISPATCH_VERSION_1_0 {
 }
 #[repr(C)]
 #[cfg(all(feature = "Win32_System_StationsAndDesktops", feature = "Win32_UI_WindowsAndMessaging"))]
-#[derive(Clone, Copy, Debug)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct WLX_DISPATCH_VERSION_1_1 {
     pub WlxUseCtrlAltDel: PWLX_USE_CTRL_ALT_DEL,
     pub WlxSetContextPointer: PWLX_SET_CONTEXT_POINTER,
@@ -215,10 +172,6 @@ pub struct WLX_DISPATCH_VERSION_1_1 {
     pub WlxChangePasswordNotifyEx: PWLX_CHANGE_PASSWORD_NOTIFY_EX,
 }
 #[cfg(all(feature = "Win32_System_StationsAndDesktops", feature = "Win32_UI_WindowsAndMessaging"))]
-impl windows_core::TypeKind for WLX_DISPATCH_VERSION_1_1 {
-    type TypeKind = windows_core::CopyType;
-}
-#[cfg(all(feature = "Win32_System_StationsAndDesktops", feature = "Win32_UI_WindowsAndMessaging"))]
 impl Default for WLX_DISPATCH_VERSION_1_1 {
     fn default() -> Self {
         unsafe { core::mem::zeroed() }
@@ -226,7 +179,7 @@ impl Default for WLX_DISPATCH_VERSION_1_1 {
 }
 #[repr(C)]
 #[cfg(all(feature = "Win32_System_StationsAndDesktops", feature = "Win32_UI_WindowsAndMessaging"))]
-#[derive(Clone, Copy, Debug)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct WLX_DISPATCH_VERSION_1_2 {
     pub WlxUseCtrlAltDel: PWLX_USE_CTRL_ALT_DEL,
     pub WlxSetContextPointer: PWLX_SET_CONTEXT_POINTER,
@@ -248,10 +201,6 @@ pub struct WLX_DISPATCH_VERSION_1_2 {
     pub WlxCloseUserDesktop: PWLX_CLOSE_USER_DESKTOP,
 }
 #[cfg(all(feature = "Win32_System_StationsAndDesktops", feature = "Win32_UI_WindowsAndMessaging"))]
-impl windows_core::TypeKind for WLX_DISPATCH_VERSION_1_2 {
-    type TypeKind = windows_core::CopyType;
-}
-#[cfg(all(feature = "Win32_System_StationsAndDesktops", feature = "Win32_UI_WindowsAndMessaging"))]
 impl Default for WLX_DISPATCH_VERSION_1_2 {
     fn default() -> Self {
         unsafe { core::mem::zeroed() }
@@ -259,7 +208,7 @@ impl Default for WLX_DISPATCH_VERSION_1_2 {
 }
 #[repr(C)]
 #[cfg(all(feature = "Win32_System_StationsAndDesktops", feature = "Win32_UI_WindowsAndMessaging"))]
-#[derive(Clone, Copy, Debug)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct WLX_DISPATCH_VERSION_1_3 {
     pub WlxUseCtrlAltDel: PWLX_USE_CTRL_ALT_DEL,
     pub WlxSetContextPointer: PWLX_SET_CONTEXT_POINTER,
@@ -288,10 +237,6 @@ pub struct WLX_DISPATCH_VERSION_1_3 {
     pub WlxQueryTerminalServicesData: PWLX_QUERY_TERMINAL_SERVICES_DATA,
 }
 #[cfg(all(feature = "Win32_System_StationsAndDesktops", feature = "Win32_UI_WindowsAndMessaging"))]
-impl windows_core::TypeKind for WLX_DISPATCH_VERSION_1_3 {
-    type TypeKind = windows_core::CopyType;
-}
-#[cfg(all(feature = "Win32_System_StationsAndDesktops", feature = "Win32_UI_WindowsAndMessaging"))]
 impl Default for WLX_DISPATCH_VERSION_1_3 {
     fn default() -> Self {
         unsafe { core::mem::zeroed() }
@@ -299,7 +244,7 @@ impl Default for WLX_DISPATCH_VERSION_1_3 {
 }
 #[repr(C)]
 #[cfg(all(feature = "Win32_System_StationsAndDesktops", feature = "Win32_UI_WindowsAndMessaging"))]
-#[derive(Clone, Copy, Debug)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct WLX_DISPATCH_VERSION_1_4 {
     pub WlxUseCtrlAltDel: PWLX_USE_CTRL_ALT_DEL,
     pub WlxSetContextPointer: PWLX_SET_CONTEXT_POINTER,
@@ -330,26 +275,24 @@ pub struct WLX_DISPATCH_VERSION_1_4 {
     pub WlxQueryTsLogonCredentials: PWLX_QUERY_TS_LOGON_CREDENTIALS,
 }
 #[cfg(all(feature = "Win32_System_StationsAndDesktops", feature = "Win32_UI_WindowsAndMessaging"))]
-impl windows_core::TypeKind for WLX_DISPATCH_VERSION_1_4 {
-    type TypeKind = windows_core::CopyType;
-}
-#[cfg(all(feature = "Win32_System_StationsAndDesktops", feature = "Win32_UI_WindowsAndMessaging"))]
 impl Default for WLX_DISPATCH_VERSION_1_4 {
     fn default() -> Self {
         unsafe { core::mem::zeroed() }
     }
 }
+pub const WLX_DLG_INPUT_TIMEOUT: u32 = 102u32;
+pub const WLX_DLG_SAS: u32 = 101u32;
+pub const WLX_DLG_SCREEN_SAVER_TIMEOUT: u32 = 103u32;
+pub const WLX_DLG_USER_LOGOFF: u32 = 104u32;
+pub const WLX_LOGON_OPT_NO_PROFILE: u32 = 1u32;
 #[repr(C)]
-#[derive(Clone, Copy, Debug, Eq, PartialEq)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct WLX_MPR_NOTIFY_INFO {
     pub pszUserName: windows_core::PWSTR,
     pub pszDomain: windows_core::PWSTR,
     pub pszPassword: windows_core::PWSTR,
     pub pszOldPassword: windows_core::PWSTR,
 }
-impl windows_core::TypeKind for WLX_MPR_NOTIFY_INFO {
-    type TypeKind = windows_core::CopyType;
-}
 impl Default for WLX_MPR_NOTIFY_INFO {
     fn default() -> Self {
         unsafe { core::mem::zeroed() }
@@ -357,7 +300,7 @@ impl Default for WLX_MPR_NOTIFY_INFO {
 }
 #[repr(C)]
 #[cfg(feature = "Win32_System_StationsAndDesktops")]
-#[derive(Clone, Copy, Debug)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct WLX_NOTIFICATION_INFO {
     pub Size: u32,
     pub Flags: u32,
@@ -369,31 +312,35 @@ pub struct WLX_NOTIFICATION_INFO {
     pub pStatusCallback: PFNMSGECALLBACK,
 }
 #[cfg(feature = "Win32_System_StationsAndDesktops")]
-impl windows_core::TypeKind for WLX_NOTIFICATION_INFO {
-    type TypeKind = windows_core::CopyType;
-}
-#[cfg(feature = "Win32_System_StationsAndDesktops")]
 impl Default for WLX_NOTIFICATION_INFO {
     fn default() -> Self {
         unsafe { core::mem::zeroed() }
     }
 }
+pub const WLX_OPTION_CONTEXT_POINTER: u32 = 2u32;
+pub const WLX_OPTION_DISPATCH_TABLE_SIZE: u32 = 65539u32;
+pub const WLX_OPTION_FORCE_LOGOFF_TIME: u32 = 4u32;
+pub const WLX_OPTION_IGNORE_AUTO_LOGON: u32 = 8u32;
+pub const WLX_OPTION_NO_SWITCH_ON_SAS: u32 = 9u32;
+pub const WLX_OPTION_SMART_CARD_INFO: u32 = 65538u32;
+pub const WLX_OPTION_SMART_CARD_PRESENT: u32 = 65537u32;
+pub const WLX_OPTION_USE_CTRL_ALT_DEL: u32 = 1u32;
+pub const WLX_OPTION_USE_SMART_CARD: u32 = 3u32;
+pub const WLX_PROFILE_TYPE_V1_0: u32 = 1u32;
+pub const WLX_PROFILE_TYPE_V2_0: u32 = 2u32;
 #[repr(C)]
-#[derive(Clone, Copy, Debug, Eq, PartialEq)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct WLX_PROFILE_V1_0 {
     pub dwType: u32,
     pub pszProfile: windows_core::PWSTR,
 }
-impl windows_core::TypeKind for WLX_PROFILE_V1_0 {
-    type TypeKind = windows_core::CopyType;
-}
 impl Default for WLX_PROFILE_V1_0 {
     fn default() -> Self {
         unsafe { core::mem::zeroed() }
     }
 }
 #[repr(C)]
-#[derive(Clone, Copy, Debug, Eq, PartialEq)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct WLX_PROFILE_V2_0 {
     pub dwType: u32,
     pub pszProfile: windows_core::PWSTR,
@@ -402,78 +349,71 @@ pub struct WLX_PROFILE_V2_0 {
     pub pszServerName: windows_core::PWSTR,
     pub pszEnvironment: windows_core::PWSTR,
 }
-impl windows_core::TypeKind for WLX_PROFILE_V2_0 {
-    type TypeKind = windows_core::CopyType;
-}
 impl Default for WLX_PROFILE_V2_0 {
     fn default() -> Self {
         unsafe { core::mem::zeroed() }
     }
 }
+pub const WLX_SAS_ACTION_DELAYED_FORCE_LOGOFF: u32 = 16u32;
+pub const WLX_SAS_ACTION_FORCE_LOGOFF: u32 = 9u32;
+pub const WLX_SAS_ACTION_LOCK_WKSTA: u32 = 3u32;
+pub const WLX_SAS_ACTION_LOGOFF: u32 = 4u32;
+pub const WLX_SAS_ACTION_LOGON: u32 = 1u32;
+pub const WLX_SAS_ACTION_NONE: u32 = 2u32;
+pub const WLX_SAS_ACTION_PWD_CHANGED: u32 = 6u32;
+pub const WLX_SAS_ACTION_RECONNECTED: u32 = 15u32;
+pub const WLX_SAS_ACTION_SHUTDOWN: WLX_SHUTDOWN_TYPE = WLX_SHUTDOWN_TYPE(5u32);
+pub const WLX_SAS_ACTION_SHUTDOWN_HIBERNATE: u32 = 14u32;
+pub const WLX_SAS_ACTION_SHUTDOWN_POWER_OFF: WLX_SHUTDOWN_TYPE = WLX_SHUTDOWN_TYPE(10u32);
+pub const WLX_SAS_ACTION_SHUTDOWN_REBOOT: WLX_SHUTDOWN_TYPE = WLX_SHUTDOWN_TYPE(11u32);
+pub const WLX_SAS_ACTION_SHUTDOWN_SLEEP: u32 = 12u32;
+pub const WLX_SAS_ACTION_SHUTDOWN_SLEEP2: u32 = 13u32;
+pub const WLX_SAS_ACTION_SWITCH_CONSOLE: u32 = 17u32;
+pub const WLX_SAS_ACTION_TASKLIST: u32 = 7u32;
+pub const WLX_SAS_ACTION_UNLOCK_WKSTA: u32 = 8u32;
+pub const WLX_SAS_TYPE_AUTHENTICATED: u32 = 7u32;
+pub const WLX_SAS_TYPE_CTRL_ALT_DEL: u32 = 1u32;
+pub const WLX_SAS_TYPE_MAX_MSFT_VALUE: u32 = 127u32;
+pub const WLX_SAS_TYPE_SCRNSVR_ACTIVITY: u32 = 3u32;
+pub const WLX_SAS_TYPE_SCRNSVR_TIMEOUT: u32 = 2u32;
+pub const WLX_SAS_TYPE_SC_FIRST_READER_ARRIVED: u32 = 8u32;
+pub const WLX_SAS_TYPE_SC_INSERT: u32 = 5u32;
+pub const WLX_SAS_TYPE_SC_LAST_READER_REMOVED: u32 = 9u32;
+pub const WLX_SAS_TYPE_SC_REMOVE: u32 = 6u32;
+pub const WLX_SAS_TYPE_SWITCHUSER: u32 = 10u32;
+pub const WLX_SAS_TYPE_TIMEOUT: u32 = 0u32;
+pub const WLX_SAS_TYPE_USER_LOGOFF: u32 = 4u32;
 #[repr(C)]
-#[derive(Clone, Copy, Debug, Eq, PartialEq)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct WLX_SC_NOTIFICATION_INFO {
     pub pszCard: windows_core::PWSTR,
     pub pszReader: windows_core::PWSTR,
     pub pszContainer: windows_core::PWSTR,
     pub pszCryptoProvider: windows_core::PWSTR,
 }
-impl windows_core::TypeKind for WLX_SC_NOTIFICATION_INFO {
-    type TypeKind = windows_core::CopyType;
-}
 impl Default for WLX_SC_NOTIFICATION_INFO {
     fn default() -> Self {
         unsafe { core::mem::zeroed() }
     }
 }
+#[repr(transparent)]
+#[derive(Clone, Copy, Debug, Default, Eq, PartialEq)]
+pub struct WLX_SHUTDOWN_TYPE(pub u32);
 #[repr(C)]
-#[derive(Clone, Copy, Debug, Eq, PartialEq)]
+#[derive(Clone, Copy, Debug, PartialEq)]
 pub struct WLX_TERMINAL_SERVICES_DATA {
     pub ProfilePath: [u16; 257],
     pub HomeDir: [u16; 257],
     pub HomeDirDrive: [u16; 4],
 }
-impl windows_core::TypeKind for WLX_TERMINAL_SERVICES_DATA {
-    type TypeKind = windows_core::CopyType;
-}
 impl Default for WLX_TERMINAL_SERVICES_DATA {
     fn default() -> Self {
         unsafe { core::mem::zeroed() }
     }
 }
-pub type PFNMSGECALLBACK = Option<unsafe extern "system" fn(bverbose: super::super::Foundation::BOOL, lpmessage: windows_core::PCWSTR) -> u32>;
-pub type PWLX_ASSIGN_SHELL_PROTECTION = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, htoken: super::super::Foundation::HANDLE, hprocess: super::super::Foundation::HANDLE, hthread: super::super::Foundation::HANDLE) -> i32>;
-pub type PWLX_CHANGE_PASSWORD_NOTIFY = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, pmprinfo: *mut WLX_MPR_NOTIFY_INFO, dwchangeinfo: u32) -> i32>;
-pub type PWLX_CHANGE_PASSWORD_NOTIFY_EX = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, pmprinfo: *mut WLX_MPR_NOTIFY_INFO, dwchangeinfo: u32, providername: windows_core::PCWSTR, reserved: *mut core::ffi::c_void) -> i32>;
-#[cfg(feature = "Win32_System_StationsAndDesktops")]
-pub type PWLX_CLOSE_USER_DESKTOP = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, pdesktop: *mut WLX_DESKTOP, htoken: super::super::Foundation::HANDLE) -> super::super::Foundation::BOOL>;
-#[cfg(feature = "Win32_System_StationsAndDesktops")]
-pub type PWLX_CREATE_USER_DESKTOP = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, htoken: super::super::Foundation::HANDLE, flags: u32, pszdesktopname: windows_core::PCWSTR, ppdesktop: *mut *mut WLX_DESKTOP) -> super::super::Foundation::BOOL>;
-#[cfg(feature = "Win32_UI_WindowsAndMessaging")]
-pub type PWLX_DIALOG_BOX = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, hinst: super::super::Foundation::HANDLE, lpsztemplate: windows_core::PCWSTR, hwndowner: super::super::Foundation::HWND, dlgprc: super::super::UI::WindowsAndMessaging::DLGPROC) -> i32>;
-#[cfg(feature = "Win32_UI_WindowsAndMessaging")]
-pub type PWLX_DIALOG_BOX_INDIRECT = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, hinst: super::super::Foundation::HANDLE, hdialogtemplate: *mut super::super::UI::WindowsAndMessaging::DLGTEMPLATE, hwndowner: super::super::Foundation::HWND, dlgprc: super::super::UI::WindowsAndMessaging::DLGPROC) -> i32>;
-#[cfg(feature = "Win32_UI_WindowsAndMessaging")]
-pub type PWLX_DIALOG_BOX_INDIRECT_PARAM = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, hinst: super::super::Foundation::HANDLE, hdialogtemplate: *mut super::super::UI::WindowsAndMessaging::DLGTEMPLATE, hwndowner: super::super::Foundation::HWND, dlgprc: super::super::UI::WindowsAndMessaging::DLGPROC, dwinitparam: super::super::Foundation::LPARAM) -> i32>;
-#[cfg(feature = "Win32_UI_WindowsAndMessaging")]
-pub type PWLX_DIALOG_BOX_PARAM = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, hinst: super::super::Foundation::HANDLE, lpsztemplate: windows_core::PCWSTR, hwndowner: super::super::Foundation::HWND, dlgprc: super::super::UI::WindowsAndMessaging::DLGPROC, dwinitparam: super::super::Foundation::LPARAM) -> i32>;
-pub type PWLX_DISCONNECT = Option<unsafe extern "system" fn() -> super::super::Foundation::BOOL>;
-pub type PWLX_GET_OPTION = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, option: u32, value: *mut usize) -> super::super::Foundation::BOOL>;
-#[cfg(feature = "Win32_System_StationsAndDesktops")]
-pub type PWLX_GET_SOURCE_DESKTOP = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, ppdesktop: *mut *mut WLX_DESKTOP) -> super::super::Foundation::BOOL>;
-pub type PWLX_MESSAGE_BOX = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, hwndowner: super::super::Foundation::HWND, lpsztext: windows_core::PCWSTR, lpsztitle: windows_core::PCWSTR, fustyle: u32) -> i32>;
-pub type PWLX_QUERY_CLIENT_CREDENTIALS = Option<unsafe extern "system" fn(pcred: *mut WLX_CLIENT_CREDENTIALS_INFO_V1_0) -> super::super::Foundation::BOOL>;
-pub type PWLX_QUERY_CONSOLESWITCH_CREDENTIALS = Option<unsafe extern "system" fn(pcred: *mut WLX_CONSOLESWITCH_CREDENTIALS_INFO_V1_0) -> u32>;
-pub type PWLX_QUERY_IC_CREDENTIALS = Option<unsafe extern "system" fn(pcred: *mut WLX_CLIENT_CREDENTIALS_INFO_V1_0) -> super::super::Foundation::BOOL>;
-pub type PWLX_QUERY_TERMINAL_SERVICES_DATA = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, ptsdata: *mut WLX_TERMINAL_SERVICES_DATA, username: windows_core::PCWSTR, domain: windows_core::PCWSTR) -> u32>;
-pub type PWLX_QUERY_TS_LOGON_CREDENTIALS = Option<unsafe extern "system" fn(pcred: *mut WLX_CLIENT_CREDENTIALS_INFO_V2_0) -> super::super::Foundation::BOOL>;
-pub type PWLX_SAS_NOTIFY = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, dwsastype: u32)>;
-pub type PWLX_SET_CONTEXT_POINTER = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, pwlxcontext: *mut core::ffi::c_void)>;
-pub type PWLX_SET_OPTION = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, option: u32, value: usize, oldvalue: *mut usize) -> super::super::Foundation::BOOL>;
-#[cfg(feature = "Win32_System_StationsAndDesktops")]
-pub type PWLX_SET_RETURN_DESKTOP = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, pdesktop: *mut WLX_DESKTOP) -> super::super::Foundation::BOOL>;
-pub type PWLX_SET_TIMEOUT = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE, timeout: u32) -> super::super::Foundation::BOOL>;
-pub type PWLX_SWITCH_DESKTOP_TO_USER = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE) -> i32>;
-pub type PWLX_SWITCH_DESKTOP_TO_WINLOGON = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE) -> i32>;
-pub type PWLX_USE_CTRL_ALT_DEL = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE)>;
-pub type PWLX_WIN31_MIGRATE = Option<unsafe extern "system" fn(hwlx: super::super::Foundation::HANDLE)>;
+pub const WLX_VERSION_1_0: u32 = 65536u32;
+pub const WLX_VERSION_1_1: u32 = 65537u32;
+pub const WLX_VERSION_1_2: u32 = 65538u32;
+pub const WLX_VERSION_1_3: u32 = 65539u32;
+pub const WLX_VERSION_1_4: u32 = 65540u32;
+pub const WLX_WM_SAS: u32 = 1625u32;
